"""
ZeptoMail — A Python client for the ZeptoMail transactional email API.

Usage::

    from zeptomail import Config, Email, MimeType

    config = Config(api_key="your-api-key")
    email  = Email(config)
    response = email.send(
        from_="noreply@example.com",
        from_name="My App",
        to=["user@example.com"],
        subject="Hello!",
        html_body="<h1>Hi there</h1>",
    )
"""

from zeptomail.client import Config, Email
from zeptomail.mime import MimeType, UNSUPPORTED_ATTACHMENT_FORMATS
from zeptomail.utils import bytes_to_base64
from zeptomail.exceptions import MimeTypeError, ZeptoMailError, ZeptoMailAPIError

__all__ = [
    "Config",
    "Email",
    "MimeType",
    "MimeTypeError",
    "ZeptoMailError",
    "ZeptoMailAPIError",
    "UNSUPPORTED_ATTACHMENT_FORMATS",
    "bytes_to_base64",
]

__version__ = "0.1.0"
